@@ -1,9 +1,9 @@
 //#![allow(dead_code)]
 
+pub use crate::context::InfoContext;
 use std::os::raw::c_char;
 use std::str::Utf8Error;
 use strum_macros::AsRefStr;
-
 extern crate num_traits;
 
 use libc::size_t;
@@ -61,14 +61,21 @@ fn from_byte_string(byte_str: *const c_char, length: size_t) -> Result<String, U
     String::from_utf8(vec_str).map_err(|e| e.utf8_error())
 }
 
-pub fn base_info_func(ctx: *mut RedisModuleInfoCtx, for_crash_report: bool) {
+pub fn base_info_func(
+    ctx: &InfoContext,
+    for_crash_report: bool,
+    extended_info_func: Option<fn(&InfoContext, bool)>,
+) {
     if !for_crash_report {
-        return;
+        if let Some(func) = extended_info_func {
+            func(ctx, for_crash_report);
+            return;
+        }
     }
     // add rust trace into the crash report
-    if add_info_section(ctx, Some("trace")) == Status::Ok {
+    if ctx.add_info_section(Some("trace")) == Status::Ok {
         let current_backtrace = Backtrace::new();
         let trace = format!("{:?}", current_backtrace);
-        raw::add_info_field_str(ctx, "trace", &trace);
+        ctx.add_info_field_str("trace", &trace);
     }
 }
